Management Network
==================

Each management realm controller running on the master node stores its configuration and run-time
information in an embedded database.

.. note::

    Each management realm has its own dedicated management realm controller database. This database
    is separate for each management realm and not accessed by any other management realm controller.

---------

.. toctree::
    :maxdepth: 3

    network
    exchange
